Comment

Comment by jhpratt

I benchmarked this out of curiosity. Even using the bitshift and eliding the bounds checks (unsoundly), it's 22% slower than my optimized version.
parent jhpratt 1 year ago

No comments yet

Be the first to share your thoughts.

Live from the official Hacker News API

A modern reader for Hacker News · SvelteKit + Skeleton